cwlVersion: v1.2
class: Workflow
doc: >-
  The workflow starts with selecting KLF4 as the search term. Gene sets with set
  labels containing KLF4 were queried from Enrichr[1]. Identified matching terms
  from the ENCODE TF ChIP-seq 2015[2] library were assembled into a collection
  of gene sets. A GMT was extracted from the Enrichr results for
  ENCODE_TF_ChIP-seq_2015. Identified matching terms from the ChEA 2022[4]
  library were assembled into a collection of gene sets. A GMT was extracted
  from the Enrichr results for ChEA_2022. Identified matching terms from the
  ARCHS4 TF Co-Expression[5] library were assembled into a collection of gene
  sets. A GMT was extracted from the Enrichr results for ARCHS4_TFs_Coexp.
  Multiple GMTs were combined into one GMT. A consensus gene set was created by
  only retaining genes that appear in at least two sets. The gene set was
  submitted to Enrichr[1]. The gene set was enriched against the GTEx Tissues V8
  2023[6] library to identify statistically significant GTEx Tissue Signatures. 

  1. Xie, Z. et al. Gene Set Knowledge Discovery with Enrichr. Current Protocols
  vol. 1 (2021). doi:10.1002/cpz1.90

  2. An integrated encyclopedia of DNA elements in the human genome. Nature vol.
  489 57–74 (2012). doi:10.1038/nature11247

  4. Keenan, A. B. et al. ChEA3: transcription factor enrichment analysis by
  orthogonal omics integration. Nucleic Acids Research vol. 47 W212–W224 (2019).
  doi:10.1093/nar/gkz446

  5. Lachmann, A. et al. Massive mining of publicly available RNA-seq data from
  human and mouse. Nature Communications vol. 9 (2018).
  doi:10.1038/s41467-018-03751-6

  6. Lonsdale, J. et al. The Genotype-Tissue Expression (GTEx) project. Nature
  Genetics vol. 45 580–585 (2013). doi:10.1038/ng.2653
requirements: {}
inputs:
  step-1-data:
    label: Gene Input
    doc: Start with a Gene
    type: File
outputs:
  step-1-output:
    label: Gene
    doc: Gene Term
    type: File
    outputSource: step-1/output
  step-2-output:
    label: Enrichr Term Search Results
    doc: Results of an Enrichr Term Search
    type: File
    outputSource: step-2/output
  step-3-output:
    label: Enrichr Gene Set
    doc: Set of Genes
    type: File
    outputSource: step-3/output
  step-4-output:
    label: Gene Matrix Transpose
    doc: Terms mapped to genes
    type: File
    outputSource: step-4/output
  step-5-output:
    label: Enrichr Gene Set
    doc: Set of Genes
    type: File
    outputSource: step-5/output
  step-6-output:
    label: Gene Matrix Transpose
    doc: Terms mapped to genes
    type: File
    outputSource: step-6/output
  step-7-output:
    label: Enrichr Gene Set
    doc: Set of Genes
    type: File
    outputSource: step-7/output
  step-8-output:
    label: Gene Matrix Transpose
    doc: Terms mapped to genes
    type: File
    outputSource: step-8/output
  step-9-output:
    label: Gene Matrix Transpose
    doc: Terms mapped to genes
    type: File
    outputSource: step-9/output
  step-10-output:
    label: Gene Set
    doc: Set of Genes
    type: File
    outputSource: step-10/output
  step-11-output:
    label: Enrichr Enrichment Analysis
    doc: A gene set submitted to [Enrichr](https://maayanlab.cloud/Enrichr/)
    type: File
    outputSource: step-11/output
  step-12-output:
    label: Enrichr Scored Tissues
    doc: ZScores of Tissues
    type: File
    outputSource: step-12/output
steps:
  step-1:
    run: Input[Gene].cwl
    label: Gene Input
    doc: Start with a Gene
    in:
      data:
        source: step-1-data
      outputFilename:
        default: step-1-output.json
    out:
      - output
  step-2:
    run: EnrichrTermSearch[Gene].cwl
    label: Extract Gene Sets Containing the Gene in the Set Label
    doc: Find Gene Terms in Enrichr Libraries
    in:
      inputs.term:
        label: Gene
        source: step-1/output
      outputFilename:
        default: step-2-output.json
    out:
      - output
  step-3:
    run: ExtractEnrichrTermSearch[ENCODE_TF_ChIP-seq_2015].cwl
    label: Extract ENCODE Transcription Factors Targeting the Term Search
    doc: Extract Terms from the ENCODE TF ChIP-seq 2015 Library
    in:
      inputs.searchResults:
        label: Enrichr Term Search Results
        source: step-2/output
      outputFilename:
        default: step-3-output.json
    out:
      - output
  step-4:
    run: EnrichrSetTToGMT[Gene].cwl
    label: Enrichr Gene Set as GMT
    doc: Load Enrichr set as GMT
    in:
      inputs.enrichrset:
        label: Enrichr Gene Set
        source: step-3/output
      outputFilename:
        default: step-4-output.json
    out:
      - output
  step-5:
    run: ExtractEnrichrTermSearch[ChEA_2022].cwl
    label: Extract ChEA Transcription Factors Targeting the Term Search
    doc: Extract Terms from the ChEA 2022 Library
    in:
      inputs.searchResults:
        label: Enrichr Term Search Results
        source: step-2/output
      outputFilename:
        default: step-5-output.json
    out:
      - output
  step-6:
    run: EnrichrSetTToGMT[Gene].cwl
    label: Enrichr Gene Set as GMT
    doc: Load Enrichr set as GMT
    in:
      inputs.enrichrset:
        label: Enrichr Gene Set
        source: step-5/output
      outputFilename:
        default: step-6-output.json
    out:
      - output
  step-7:
    run: ExtractEnrichrTermSearch[ARCHS4_TFs_Coexp].cwl
    label: Extract ARCHS4 Transcription Factors Correlated with the Term Search
    doc: Extract Terms from the ARCHS4 TF Co-Expression Library
    in:
      inputs.searchResults:
        label: Enrichr Term Search Results
        source: step-2/output
      outputFilename:
        default: step-7-output.json
    out:
      - output
  step-8:
    run: EnrichrSetTToGMT[Gene].cwl
    label: Enrichr Gene Set as GMT
    doc: Load Enrichr set as GMT
    in:
      inputs.enrichrset:
        label: Enrichr Gene Set
        source: step-7/output
      outputFilename:
        default: step-8-output.json
    out:
      - output
  step-9:
    run: GMTConcatenate.cwl
    label: Concatenate GMTs
    doc: Join several GMTs into one
    in:
      inputs.gmts:0:
        label: Gene Matrix Transpose
        source: step-4/output
      inputs.gmts:1:
        label: Gene Matrix Transpose
        source: step-6/output
      inputs.gmts:2:
        label: Gene Matrix Transpose
        source: step-8/output
      outputFilename:
        default: step-9-output.json
    out:
      - output
  step-10:
    run: GMTConsensus.cwl
    label: Compute Consensus Gene Set
    doc: Find genes which appear in more than one set
    in:
      inputs.gmt:
        label: Gene Matrix Transpose
        source: step-9/output
      outputFilename:
        default: step-10-output.json
    out:
      - output
  step-11:
    run: EnrichrGenesetSearch.cwl
    label: Enrichr Enrichment Analysis
    doc: Perform Enrichment Analysis
    in:
      inputs.geneset:
        label: Gene Set
        source: step-10/output
      outputFilename:
        default: step-11-output.json
    out:
      - output
  step-12:
    run: ExtractEnrichrGenesetSearch[GTEx_Tissues_V8_2023].cwl
    label: Extract Enriched GTEx Tissue Signatures
    doc: Extract Significant Terms from the GTEx Tissues V8 2023 Library
    in:
      inputs.searchResults:
        label: Enrichr Enrichment Analysis
        source: step-11/output
      outputFilename:
        default: step-12-output.json
    out:
      - output
